==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerListFluent<A extends V2beta1HorizontalPodAutoscalerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V2beta1HorizontalPodAutoscaler item);
    public A setToItems(int index,V2beta1HorizontalPodAutoscaler item);
    public A addToItems(V2beta1HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<V2beta1HorizontalPodAutoscaler> items);
    public A removeFromItems(V2beta1HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<V2beta1HorizontalPodAutoscaler> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1HorizontalPodAutoscaler> getItems();
    public List<V2beta1HorizontalPodAutoscaler> buildItems();
    public V2beta1HorizontalPodAutoscaler buildItem(int index);
    public V2beta1HorizontalPodAutoscaler buildFirstItem();
    public V2beta1HorizontalPodAutoscaler buildLastItem();
    public V2beta1HorizontalPodAutoscaler buildMatchingItem(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<V2beta1HorizontalPodAutoscaler> items);
    public A withItems(V2beta1HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(V2beta1HorizontalPodAutoscaler item);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,V2beta1HorizontalPodAutoscaler item);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerFluent<V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerListFluent<A extends V2beta1HorizontalPodAutoscalerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V2beta1HorizontalPodAutoscaler item);
    public A setToItems(int index,V2beta1HorizontalPodAutoscaler item);
    public A addToItems(V2beta1HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<V2beta1HorizontalPodAutoscaler> items);
    public A removeFromItems(V2beta1HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<V2beta1HorizontalPodAutoscaler> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1HorizontalPodAutoscaler> getItems();
    public List<V2beta1HorizontalPodAutoscaler> buildItems();
    public V2beta1HorizontalPodAutoscaler buildItem(int index);
    public V2beta1HorizontalPodAutoscaler buildFirstItem();
    public V2beta1HorizontalPodAutoscaler buildLastItem();
    public V2beta1HorizontalPodAutoscaler buildMatchingItem(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<V2beta1HorizontalPodAutoscaler> items);
    public A withItems(V2beta1HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(V2beta1HorizontalPodAutoscaler item);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,V2beta1HorizontalPodAutoscaler item);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V2beta1HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadata();
    public V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerFluent<V2beta1HorizontalPodAutoscalerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V2beta1HorizontalPodAutoscalerListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
